embassy-usb

Crates

git

Versions

default

Flavors

AudioSourceControlHandler

Struct AudioSourceControlHandler 

pub struct AudioSourceControlHandler { /* private fields */ }
Implementation of the logic for Audio Control requests (e.g., volume, mute)

Implementations

Source

impl AudioSourceControlHandler

pub fn new( sample_rates: &'static [u32], ep_audio_addr: EndpointAddress, ep_feedback_addr: EndpointAddress, iface_ctrl_num: InterfaceNumber, iface_stream_num: InterfaceNumber, ) -> Self

Create a new AudioSourceControlHandler

pub fn get_audio_ep_addr(&self) -> u8

Gets the audio endpoint address

pub fn get_feedback_ep_addr(&self) -> u8

Gets the feedback endpoint address

pub fn get_audio_ep_index(&self) -> usize

Gets the index part of the audio endpoint address

pub fn get_feedback_ep_index(&self) -> usize

Gets the index part of the feedback endpoint address

pub fn get_ctrl_iface_num(&self) -> u8

Gets the bInterfaceNumber of the control interface

pub fn get_stream_iface_num(&self) -> u8

Gets the bInterfaceNumber of the streaming interface